/*
 * file: pv_lock.h
 * This file is part of the libpv library.
 *
 * Copyright 2005 Pengutronix
 *
 * Please send bug reports to bugs@pengutronix.de
 *
 * See COPYING for the status of this software.
 */

#ifndef PV_LOCK_H
#define PV_LOCK_H

#include <libpv_config.h>

#include <errno.h>

#include <sys/sem.h>
#include <sys/stat.h>
#include <sys/types.h>

#include <pv_types.h>

#ifdef _SEM_SEMUN_UNDEFINED
union semun {
	int			val;
	struct semid_ds		*buf;
	unsigned short int	*array;
	struct seminfo		*__buf;
};
#endif

static inline void pv_lock_lock(struct pv_engine	*pv_engine)
{
	static struct sembuf op = {0, -1, SEM_UNDO};
	if (semop(pv_engine->pv_sem, &op, 1) < 0) {
		perror("pv_lock");
	}
}


static inline void pv_lock_unlock(struct pv_engine	*pv_engine)
{
	static struct sembuf op = {0, 1, SEM_UNDO};

	if (semop(pv_engine->pv_sem, &op, 1) < 0) {
		perror("pv_unlock");
	}
}

int pv_lock_init	(struct pv_engine	*engine,
			 const char		*store_filename);

int pv_lock_destroy	(struct pv_engine	*engine);


#endif	/* !PV_LOCK_H */
